"use strict";
/**
 * Exposes common HTTP errors with a preconfigured `statusCode` for convenience.
 * This does not mean you have to use HTTP to use them, it's just that
 * HTTP has already defined a nice set of common error types, and tacking
 * on the HTTP status code makes it easier to consume in HTTP apps.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHttpErrorConstructorForStatusCode = exports.NetworkAuthenticationRequired = exports.NotExtended = exports.LoopDetected = exports.InsufficientStorage = exports.VariantAlsoNegotiates = exports.HttpVersionNotSupported = exports.GatewayTimeout = exports.ServiceUnavailable = exports.BadGateway = exports.NotImplemented = exports.GeneralError = exports.UnavailableForLegalReasons = exports.RequestHeaderFieldsTooLarge = exports.TooManyRequests = exports.PreconditionRequired = exports.UpgradeRequired = exports.TooEarly = exports.FailedDependency = exports.Locked = exports.Unprocessable = exports.MisdirectedRequest = exports.IAmATeapot = exports.ExpectationFailed = exports.RequestRangeNotSatisfiable = exports.UnsupportedMediaType = exports.UriTooLong = exports.PayloadTooLarge = exports.PreconditionFailed = exports.LengthRequired = exports.Gone = exports.Conflict = exports.Timeout = exports.ProxyAuthenticationRequired = exports.NotAcceptable = exports.MethodNotAllowed = exports.NotFound = exports.Forbidden = exports.PaymentRequired = exports.NotAuthenticated = exports.BadRequest = void 0;
const make_error_class_1 = require("./make-error-class");
/** *********************************************
 * List of all CLIENT Errors (4xx)
 */
/**
 * Creates a `BadRequest` error.
 */
class BadRequest extends MakeHttpError(400, 'Bad Request') {
}
exports.BadRequest = BadRequest;
/**
 * Creates a `NotAuthenticated` error.
 */
class NotAuthenticated extends MakeHttpError(401, 'Not Authenticated') {
}
exports.NotAuthenticated = NotAuthenticated;
/**
 * Creates a `PaymentRequired` error.
 */
class PaymentRequired extends MakeHttpError(402, 'Payment Required') {
}
exports.PaymentRequired = PaymentRequired;
/**
 * Creates a `Forbidden` error.
 */
class Forbidden extends MakeHttpError(403, 'Forbidden') {
}
exports.Forbidden = Forbidden;
/**
 * Creates a `NotFound` error.
 */
class NotFound extends MakeHttpError(404, 'Not Found') {
}
exports.NotFound = NotFound;
/**
 * Creates a `MethodNotAllowed` error.
 */
class MethodNotAllowed extends MakeHttpError(405, 'Method Not Allowed') {
}
exports.MethodNotAllowed = MethodNotAllowed;
/**
 * Creates a `NotAcceptable` error.
 */
class NotAcceptable extends MakeHttpError(406, 'Not Acceptable') {
}
exports.NotAcceptable = NotAcceptable;
/**
 * Creates a `ProxyAuthenticationRequired` error.
 */
class ProxyAuthenticationRequired extends MakeHttpError(407, 'Proxy Authentication Required') {
}
exports.ProxyAuthenticationRequired = ProxyAuthenticationRequired;
/**
 * Creates a `Timeout` error.
 */
class Timeout extends MakeHttpError(408, 'Timeout') {
}
exports.Timeout = Timeout;
/**
 * Creates a `Conflict` error.
 */
class Conflict extends MakeHttpError(409, 'Conflict') {
}
exports.Conflict = Conflict;
/**
 * Creates a `Gone` error.
 */
class Gone extends MakeHttpError(410, 'Gone') {
}
exports.Gone = Gone;
/**
 * Creates a `LengthRequired` error.
 */
class LengthRequired extends MakeHttpError(411, 'Length Required') {
}
exports.LengthRequired = LengthRequired;
/**
 * Creates a `PreconditionFailed` error.
 */
class PreconditionFailed extends MakeHttpError(412, 'Precondition Failed') {
}
exports.PreconditionFailed = PreconditionFailed;
/**
 * Creates a `PayloadTooLarge` error.
 */
class PayloadTooLarge extends MakeHttpError(413, 'Payload Too Large') {
}
exports.PayloadTooLarge = PayloadTooLarge;
/**
 * Creates a `UriTooLong` error.
 */
class UriTooLong extends MakeHttpError(414, 'URI Too Long') {
}
exports.UriTooLong = UriTooLong;
/**
 * Creates a `UnsupportedMediaType` error.
 */
class UnsupportedMediaType extends MakeHttpError(415, 'Unsupported Media Type') {
}
exports.UnsupportedMediaType = UnsupportedMediaType;
/**
 * Creates a `RequestRangeNotSatisfiable` error.
 */
class RequestRangeNotSatisfiable extends MakeHttpError(416, 'Request Range Not Satifiable') {
}
exports.RequestRangeNotSatisfiable = RequestRangeNotSatisfiable;
/**
 * Creates a `ExpectationFailed` error.
 */
class ExpectationFailed extends MakeHttpError(417, 'Expectation Failed') {
}
exports.ExpectationFailed = ExpectationFailed;
/**
 * Creates a `IAmATeapot` error.
 */
class IAmATeapot extends MakeHttpError(418, 'I am a Teapot') {
}
exports.IAmATeapot = IAmATeapot;
/**
 * Creates a `MisdirectedRequest` error.
 */
class MisdirectedRequest extends MakeHttpError(421, 'Misdirected Request') {
}
exports.MisdirectedRequest = MisdirectedRequest;
/**
 * Creates a `Unprocessable` error.
 */
class Unprocessable extends MakeHttpError(422, 'Unprocessable') {
}
exports.Unprocessable = Unprocessable;
/**
 * Creates a `Locked` error.
 */
class Locked extends MakeHttpError(423, 'Locked') {
}
exports.Locked = Locked;
/**
 * Creates a `FailedDependency` error.
 */
class FailedDependency extends MakeHttpError(424, 'Failed Dependency') {
}
exports.FailedDependency = FailedDependency;
/**
 * Creates a `TooEarly` error.
 */
class TooEarly extends MakeHttpError(425, 'Too Early') {
}
exports.TooEarly = TooEarly;
/**
 * Creates a `UpgradeRequired` error.
 */
class UpgradeRequired extends MakeHttpError(426, 'Upgrade Required') {
}
exports.UpgradeRequired = UpgradeRequired;
/**
 * Creates a `PreconditionRequired` error.
 */
class PreconditionRequired extends MakeHttpError(428, 'Precondition Required') {
}
exports.PreconditionRequired = PreconditionRequired;
/**
 * Creates a `TooManyRequests` error.
 */
class TooManyRequests extends MakeHttpError(429, 'Too Many Requests') {
}
exports.TooManyRequests = TooManyRequests;
/**
 * Creates a `RequestHeaderFieldsTooLarge` error.
 */
class RequestHeaderFieldsTooLarge extends MakeHttpError(431, 'Request Header Fields Too Large') {
}
exports.RequestHeaderFieldsTooLarge = RequestHeaderFieldsTooLarge;
/**
 * Creates a `UnavailableForLegalReasons` error.
 */
class UnavailableForLegalReasons extends MakeHttpError(451, 'Unavailable For Legal Reasons') {
}
exports.UnavailableForLegalReasons = UnavailableForLegalReasons;
/** *********************************************
 * List of all SERVER Errors (5xx)
 */
/**
 * Creates a `GeneralError` error.
 * This is basically some kind of `InternalServerError` error.
 */
class GeneralError extends MakeHttpError(500, 'General Error') {
}
exports.GeneralError = GeneralError;
/**
 * Creates a `NotImplemented` error.
 */
class NotImplemented extends MakeHttpError(501, 'Not Implemented') {
}
exports.NotImplemented = NotImplemented;
/**
 * Creates a `BadGateway` error.
 */
class BadGateway extends MakeHttpError(502, 'Bad Gateway') {
}
exports.BadGateway = BadGateway;
/**
 * Creates a `ServiceUnavailable` error.
 */
class ServiceUnavailable extends MakeHttpError(503, 'Service Unavailable') {
}
exports.ServiceUnavailable = ServiceUnavailable;
/**
 * Creates a `GatewayTimeout` error.
 */
class GatewayTimeout extends MakeHttpError(504, 'Gateway Timeout') {
}
exports.GatewayTimeout = GatewayTimeout;
/**
 * Creates a `HttpVersionNotSupported` error.
 */
class HttpVersionNotSupported extends MakeHttpError(505, 'HTTP Version Not Supported') {
}
exports.HttpVersionNotSupported = HttpVersionNotSupported;
/**
 * Creates a `VariantAlsoNegotiates` error.
 */
class VariantAlsoNegotiates extends MakeHttpError(506, 'Variant Also Negotiates') {
}
exports.VariantAlsoNegotiates = VariantAlsoNegotiates;
/**
 * Creates a `InsufficientStorage` error.
 */
class InsufficientStorage extends MakeHttpError(507, 'Insufficient Storage') {
}
exports.InsufficientStorage = InsufficientStorage;
/**
 * Creates a `LoopDetected` error.
 */
class LoopDetected extends MakeHttpError(508, 'Loop Detected') {
}
exports.LoopDetected = LoopDetected;
/**
 * Creates a `NotExtended` error.
 */
class NotExtended extends MakeHttpError(510, 'Not Extended') {
}
exports.NotExtended = NotExtended;
/**
 * Creates a `NetworkAuthenticationRequired` error.
 */
class NetworkAuthenticationRequired extends MakeHttpError(511, 'Network Authentication Required') {
}
exports.NetworkAuthenticationRequired = NetworkAuthenticationRequired;
/**
 * Gets an error constructor for a HTTP status code.
 *
 * @param statusCode
 */
function getHttpErrorConstructorForStatusCode(statusCode) {
    /* istanbul ignore next */
    switch (statusCode) {
        case 400:
            return BadRequest;
        case 401:
            return NotAuthenticated;
        case 402:
            return PaymentRequired;
        case 403:
            return Forbidden;
        case 404:
            return NotFound;
        case 405:
            return MethodNotAllowed;
        case 406:
            return NotAcceptable;
        case 407:
            return ProxyAuthenticationRequired;
        case 408:
            return Timeout;
        case 409:
            return Conflict;
        case 410:
            return Gone;
        case 411:
            return LengthRequired;
        case 412:
            return PreconditionFailed;
        case 413:
            return PayloadTooLarge;
        case 414:
            return UriTooLong;
        case 415:
            return UnsupportedMediaType;
        case 416:
            return RequestRangeNotSatisfiable;
        case 417:
            return ExpectationFailed;
        case 418:
            return IAmATeapot;
        case 421:
            return MisdirectedRequest;
        case 422:
            return Unprocessable;
        case 423:
            return Locked;
        case 424:
            return FailedDependency;
        case 425:
            return TooEarly;
        case 426:
            return UpgradeRequired;
        case 428:
            return PreconditionRequired;
        case 429:
            return TooManyRequests;
        case 431:
            return RequestHeaderFieldsTooLarge;
        case 451:
            return UnavailableForLegalReasons;
        case 501:
            return NotImplemented;
        case 502:
            return BadGateway;
        case 503:
            return ServiceUnavailable;
        case 504:
            return GatewayTimeout;
        case 505:
            return HttpVersionNotSupported;
        case 506:
            return VariantAlsoNegotiates;
        case 507:
            return InsufficientStorage;
        case 508:
            return LoopDetected;
        case 510:
            return NotExtended;
        case 511:
            return NetworkAuthenticationRequired;
        default:
            return GeneralError;
    }
}
exports.getHttpErrorConstructorForStatusCode = getHttpErrorConstructorForStatusCode;
/**
 * Builds a HTTP status code based error class.
 *
 * @private
 * @param statusCode The status code.
 * @param message The message.
 */
function MakeHttpError(statusCode, message) {
    return (0, make_error_class_1.MakeErrorClass)(message, { statusCode });
}
//# sourceMappingURL=http.js.map