/**
 * A function being passed the retryer.
 */
export declare type Retryable<T> = (retry: (err: any) => any, attempts: number) => Promise<T>;
/**
 * Options for retrying.
 */
export interface RetryOptions {
    /**
     * How many times to try
     */
    tries: number;
    /**
     * The exponential backoff factor to use.
     */
    factor: number;
    /**
     * The minimum amount of time to wait between retries in ms
     */
    minTimeout: number;
    /**
     * The nax amount of time to wait between retries in ms
     */
    maxTimeout: number;
}
/**
 * Retries the inner function. Works the same as `promise-retry`.
 * @param fn
 */
export declare function retry<T>(fn: Retryable<T>, opts?: Partial<RetryOptions>): Promise<T>;
/**
 * Waits for `ms` amount of time.
 */
export declare function delay(ms: number): Promise<void>;
/**
 * Computes the next wait time.
 * @param minTimeout
 * @param maxTimeout
 * @param waitTime
 * @param factor
 */
export declare function computeNextWaitTime(minTimeout: number, maxTimeout: number, waitTime: number, factor: number): number;
